@@ -80,7 +80,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 			EmailPlugin.sendNotification(notification2Save, aslSession.getGroupName());
 
 		if (channels.isEmpty()) {
-			_log.info("Notification was not needed as the user decided not to be notified");
+			_log.info("Notification was not needed as "+ notification2Save.getUserid()  +" decided not to be notified for " + notification2Save.getType());
 			result = true;
 		}
 		return result;
@@ -581,24 +581,28 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventDescription, String eventType, Date startDate, Date endingDate) {
+	public boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
+		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
 		
-		SimpleDateFormat DATE_FORMAT = new SimpleDateFormat("dd-MM-yy at HH:mm");
-		
-		String notificationText = "created " +escapeHtml(eventTitle) + " in the " + aslSession.getGroupName() + " shared calendar. " +
-				"Category: " + eventType + " From: " + DATE_FORMAT.format(startDate);
+		String endDateToDisplay="";
 		if (endingDate != null) {
-			DATE_FORMAT = new SimpleDateFormat("dd/MM/yy");
-			notificationText += " to " + DATE_FORMAT.format(endingDate) + ".";
+			endDateToDisplay = " to " + spf.format(endingDate);
 		}
+	
+		StringBuilder notificationText = new StringBuilder();
+		notificationText.append("added the following event in the <b>").append(aslSession.getGroupName()).append("</b> shared calendar: ") // has done something
+		.append("<strong>").append(eventTitle).append("</strong><br />")
+		.append("<br /><strong> Time:</strong> ").append(spf.format(startDate)).append(endDateToDisplay).append("<br />")
+		.append("<br /><strong> Category: </strong> ").append(eventType);
+		
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
-				NotificationType.NEW_CALENDAR_EVENT, 
+				NotificationType.CALENDAR_ADDED_EVENT, 
 				userIdToNotify, //user no notify
-				"",  //the workflowid 
+				"",  //
 				new Date(),
 				getApplicationUrl(), 
-				notificationText,
+				notificationText.toString(),
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
